@@ -1,13 +1,11 @@
 from baseball.fetch_game import (get_game_from_url,
                                  get_game_xml_from_url,
+                                 get_game_dict_from_url,
                                  write_svg_from_url,
                                  write_svg_from_file_range,
                                  write_game_svg_and_html,
                                  get_game_generator_from_file_range,
                                  get_game_list_from_file_range,
-                                 get_game_from_xml_strings,
-                                 get_game_from_files,
-                                 get_filename_list,
                                  generate_today_game_svgs,
                                  write_games_for_date)
 
