@@ -1,8 +1,8 @@
 from collections import OrderedDict
+from json import dumps
 from textwrap import TextWrapper
 from re import search, sub, findall, escape
 
-from json import dumps
 from pytz import timezone
 
 from baseball.baseball_events import RunnerAdvance
@@ -13,7 +13,6 @@ from baseball.stats import (get_all_pitcher_stats,
                             get_team_stats,
                             get_half_inning_stats)
 
-
 POSITION_CODE_DICT = {'pitcher': 1,
                       'catcher': 2,
                       'first': 3,
@@ -111,11 +110,13 @@ STADIUM_TIMEZONE_DICT = {
     'Oakland-Alameda County Coliseum': 'America/Los_Angeles',
     'Oakland Coliseum': 'America/Los_Angeles',
     'Angel Stadium': 'America/Los_Angeles',
+    'Oracle Park': 'America/Los_Angeles',
     'Dodger Stadium': 'America/Los_Angeles',
     'Petco Park': 'America/Los_Angeles',
     'T-Mobile Park': 'America/Los_Angeles'
 }
 
+EASTERN_TIMEZONE_STR = 'America/New_York'
 
 def strip_this_suffix(pattern, suffix, input_str):
     match = search(pattern, input_str)
@@ -149,7 +150,7 @@ def strip_suffixes(input_str):
     return input_str
 
 
-class PlayerAppearance(object):
+class PlayerAppearance:
     def __init__(self, player_obj, position, start_inning_num,
                  start_inning_half, start_inning_batter_num):
         self.player_obj = player_obj
@@ -210,7 +211,7 @@ class PlayerAppearance(object):
         return return_str
 
 
-class Player(object):
+class Player:
     def __init__(self, last_name, first_name, mlb_id, obp, slg, number):
         self.last_name = last_name
         self.first_name = first_name
@@ -269,7 +270,7 @@ class Player(object):
         return return_str
 
 
-class Team(object):
+class Team:
     def __init__(self, name, abbreviation):
         self.name = name
         self.abbreviation = abbreviation
@@ -380,30 +381,29 @@ class Team(object):
         return return_str
 
 
-class Game(object):
-    def __init__(self, home_team, away_team, location, game_date_str,
-                 start_datetime=None, end_datetime=None,
-                 inning_list=None):
+class Game:
+    def __init__(self, home_team, away_team, location, game_date_str):
         self.home_team = home_team
         self.away_team = away_team
         self.location = location or ''
         self.game_date_str = game_date_str
-        self.start_datetime = start_datetime
-        self.end_datetime = end_datetime
-        self.inning_list = inning_list or []
 
+        self.start_datetime = None
+        self.end_datetime = None
+        self.inning_list = []
         self.away_batter_box_score_dict = None
         self.home_batter_box_score_dict = None
         self.away_pitcher_box_score_dict = None
         self.home_pitcher_box_score_dict = None
         self.away_team_stats = None
         self.home_team_stats = None
-        self.start_str = ''
-        self.end_str = ''
-
         self.attendance = None
         self.temp = None
         self.weather = None
+        self.expected_start_datetime = None
+        self.timezone_str = EASTERN_TIMEZONE_STR
+        self.is_postponed = False
+        self.is_doubleheader = False
 
     def json(self):
         return dumps(self._asdict())
@@ -446,19 +446,26 @@ class Game(object):
              ),
              'away_team_stats': self.away_team_stats._asdict(),
              'home_team_stats': self.home_team_stats._asdict(),
-             'start_str': self.start_str,
-             'end_str': self.end_str}
+             'attendance': self.attendance,
+             'temp': self.temp,
+             'weather': self.weather,
+             'expected_start_datetime': str(self.expected_start_datetime),
+             'timezone_str': self.timezone_str}
         )
 
     def get_svg_str(self):
         return get_game_svg_str(self)
 
     def set_gametimes(self):
+        for ballpark, this_timezone in STADIUM_TIMEZONE_DICT.items():
+            if ballpark in self.location:
+                self.timezone_str = this_timezone
+
         if not self.start_datetime:
             if self.inning_list:
                 if self.inning_list[0].top_half_appearance_list:
                     self.start_datetime = (
-                        self.inning_list[0].top_half_appearance_list[0].start_datetime
+                        self.inning_list[0].top_half_appearance_list[0].end_datetime
                     )
 
         if not self.end_datetime:
@@ -473,40 +480,6 @@ class Game(object):
                         last_inning_half_appearance_list[-1].end_datetime
                     )
 
-        if self.start_datetime:
-            self.start_str = self.start_datetime.astimezone(
-                timezone('America/New_York')
-            ).strftime(
-                '%a %b %d %Y, %-I:%M %p'
-            )
-
-            for ballpark, this_timezone in STADIUM_TIMEZONE_DICT.items():
-                if ballpark in self.location:
-                    self.start_str = self.start_datetime.astimezone(
-                        timezone(this_timezone)
-                    ).strftime(
-                        '%a %b %d %Y, %-I:%M %p'
-                    )
-        else:
-            self.start_str = ''
-
-        if self.end_datetime:
-            self.end_str = self.end_datetime.astimezone(
-                timezone('America/New_York')
-            ).strftime(
-                ' - %-I:%M %p %Z'
-            )
-
-            for ballpark, this_timezone in STADIUM_TIMEZONE_DICT.items():
-                if ballpark in self.location:
-                    self.end_str = self.end_datetime.astimezone(
-                        timezone(this_timezone)
-                    ).strftime(
-                        ' - %-I:%M %p %Z'
-                    )
-        else:
-            self.end_str = ''
-
     def set_pitching_box_score_dict(self):
         self.away_pitcher_box_score_dict = OrderedDict([])
         self.home_pitcher_box_score_dict = OrderedDict([])
@@ -549,8 +522,16 @@ class Game(object):
 
     def __repr__(self):
         return_str = '{}\n'.format(self.location)
-        if self.start_str and self.end_str:
-            return_str += '{}{}\n\n'.format(self.start_str, self.end_str)
+        if self.start_datetime and self.end_datetime:
+            start_str = self.start_datetime.astimezone(
+                timezone(self.timezone_str)
+            ).strftime('%a %b %d %Y, %-I:%M %p')
+
+            end_str = self.end_datetime.astimezone(
+                timezone(self.timezone_str)
+            ).strftime(' - %-I:%M %p %Z')
+
+            return_str += '{}{}\n\n'.format(start_str, end_str)
         else:
             return_str += '{}\n\n'.format(self.game_date_str)
 
@@ -591,7 +572,7 @@ class Game(object):
         return return_str
 
 
-class Inning(object):
+class Inning:
     def __init__(self, top_half_appearance_list, bottom_half_appearance_list):
         self.top_half_appearance_list = top_half_appearance_list
         self.bottom_half_appearance_list = bottom_half_appearance_list
@@ -632,7 +613,7 @@ class Inning(object):
         )
 
 
-class PlateAppearance(object):
+class PlateAppearance:
     def __init__(self, start_datetime, end_datetime, batting_team,
                  plate_appearance_description, plate_appearance_summary,
                  pitcher, batter, inning_outs, scoring_runners_list,
@@ -731,6 +712,9 @@ class PlateAppearance(object):
             defense_predicate_list = description_str.split(' to ')
         elif  ' to ' in description_str:
             defense_predicate_list = description_str.split(' to ')[1:]
+        elif ', ' in description_str and ' to ' not in description_str:
+            description_str = description_str.split(', ')[1]
+            defense_predicate_list = [description_str]
         else:
             defense_predicate_list = []
 
@@ -860,31 +844,32 @@ class PlateAppearance(object):
             if keyword in description_str.lower():
                 code = this_code
 
+        for keyword, this_code in [('Sac Fly', 'SF'), ('Sac Bunt', 'SH')]:
+            if keyword in self.plate_appearance_summary:
+                code = this_code
+
         if self.plate_appearance_summary == 'Fan interference':
             code = 'FI'
         elif ' out to ' in description_str and code is None:
             code = 'F'
         elif not code:
-            disqualified_description = ('out at' in description_str or
-                                        'singles' in description_str or
-                                        'doubles' in description_str or
-                                        'triples' in description_str or
-                                        'hits a home run' in description_str or
-                                        'ejected' in description_str or
-                                        'remains in the game' in description_str or
-                                        ' replaces ' in description_str or
-                                        'mound visit' in description_str.lower() or
-                                        'delay' in description_str.lower())
+            disqualified_description = (
+                'out at' in description_str or
+                'singles' in description_str or
+                'doubles' in description_str or
+                'triples' in description_str or
+                'hits a home run' in description_str or
+                'ejected' in description_str or
+                'remains in the game' in description_str or
+                ' replaces ' in description_str or
+                'mound visit' in description_str.lower() or
+                'delay' in description_str.lower()
+            )
 
             if disqualified_description:
                 code = ''
             else:
                 code = ''
-                #raise ValueError(
-                #    'No keyword found in plate description: {}'.format(
-                #        self.plate_appearance_description
-                #    )
-                #)
 
         return code
 
@@ -911,9 +896,11 @@ class PlateAppearance(object):
             )
         else:
             on_base = False
-            scorecard_summary = (
-                self.get_play_str() + throws_str + suffix_str
-            )
+            if self.get_play_str() == 'CI':
+                scorecard_summary = self.get_play_str() + suffix_str
+            else:
+                scorecard_summary = (self.get_play_str() + throws_str +
+                                     suffix_str)
 
         return on_base, scorecard_summary
 
