@@ -1,17 +1,20 @@
 from collections import namedtuple
 
+from pytz import timezone
+
 from baseball.baseball_events import (AUTOMATIC_BALL_POSITION,
                                       Substitution,
                                       Pitch,
                                       Pickoff,
                                       RunnerAdvance)
 
-
 FakePlateAppearance = namedtuple(
     'FakePlateAppearance',
     'scorecard_summary batter plate_appearance_description'
 )
 
+EASTERN_TIMEZONE_STR = 'America/New_York'
+DEFAULT_LOGO = 'baseball-fairy-161.png'
 LOGO_DICT = {
     'LAA': 'team_logos/angels.gif',
     'HOU': 'team_logos/astros.gif',
@@ -27,6 +30,7 @@ LOGO_DICT = {
     'CLE': 'team_logos/indians.gif',
     'SEA': 'team_logos/mariners.gif',
     'MIA': 'team_logos/marlins.gif',
+    'FLO': 'team_logos/marlins.gif',
     'NYM': 'team_logos/mets.gif',
     'WSH': 'team_logos/nationals.gif',
     'BAL': 'team_logos/orioles.gif',
@@ -94,13 +98,15 @@ RUNNER_SUMMARY_Y_OFFSET = 20
 PITCHER_Y = 150
 PITCHER_X = 166
 CATCHER_Y = 180
+BASE_SVG_FONT_SMALL = 11
+BASE_SVG_FONT_BIG = 22
 FIRST_BASE_Y = 115
 FIRST_BASE_X = 220
 SECOND_BASE_Y = 80
 SECOND_BASE_X = 186
 THIRD_BASE_X = 112
-SHORTSTOP_Y = 100
-SHORTSTOP_X = 140
+SHORTSTOP_Y = 90
+SHORTSTOP_X = 130
 LEFT_FIELDER_Y = 58
 LEFT_FIELDER_X = 105
 CENTER_FIELDER_Y = 35
@@ -122,6 +128,10 @@ BATTER_STATS_SPACES_MED_PLUS = 5
 BATTER_STATS_SPACES_MED = 6
 BATTER_STATS_SPACES_SMALL = 10
 BATTER_INITIAL_Y_POS = 25
+BIG_TITLE_SIZE = 55
+SMALL_TITLE_SIZE = 50
+SUMMARY_SIZE_LARGE = 43
+SUMMARY_SIZE_SMALL = 30
 RED_COLOR = '#c10000'
 BLUE_COLOR = 'blue'
 DARK_GREEN_COLOR = 'darkgreen'
@@ -377,7 +387,7 @@ BIG_SVG_TITLE = (
     '<text x="133" y="67" font-family="Arial" text-anchor="middle" '
     'font-size="50">{inning_half}</text>'
     '<text x="80" y="700" transform="rotate(-90,80,700)" '
-    'fill="black" font-size="55" font-family="Arial" text-anchor="middle" '
+    'fill="black" font-size="{title_size}" font-family="Arial" text-anchor="middle" '
     '>{game_str}</text>'
     '<text x="145" y="700" transform="rotate(-90,145,700)" '
     'fill="black" font-size="45" font-family="Arial" text-anchor="middle" '
@@ -550,7 +560,7 @@ SVG_BASE_2_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
 )
@@ -563,7 +573,7 @@ SVG_BASE_2_OUT_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
 )
@@ -574,13 +584,13 @@ SVG_BASE_3_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
     '<text x="132" y="93" font-family="Arial" text-anchor="end" '
     'font-size="22">{base_3_number}</text>'
     '<text x="132" y="114" font-family="Arial" text-anchor="end" '
-    'font-size="22">{base_3_summary}'
+    'font-size="{base_3_size}">{base_3_summary}'
     '<title id="title">{base_3_title}</title>'
     '</text>'
 )
@@ -593,13 +603,13 @@ SVG_BASE_3_OUT_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
     '<text x="132" y="93" font-family="Arial" text-anchor="end" '
     'font-size="22">{base_3_number}</text>'
     '<text x="132" y="114" font-family="Arial" text-anchor="end" '
-    'font-size="22">{base_3_summary}'
+    'font-size="{base_3_size}">{base_3_summary}'
     '<title id="title">{base_3_title}</title>'
     '</text>'
 )
@@ -614,19 +624,19 @@ SVG_BASE_4_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
     '<text x="132" y="93" font-family="Arial" text-anchor="end" '
     'font-size="22">{base_3_number}</text>'
     '<text x="132" y="114" font-family="Arial" text-anchor="end" '
-    'font-size="22">{base_3_summary}'
+    'font-size="{base_3_size}">{base_3_summary}'
     '<title id="title">{base_3_title}</title>'
     '</text>'
     '<text x="164" y="133" font-family="Arial" text-anchor="middle" '
     'font-size="22" fill="white">{base_4_number}</text>'
     '<text x="164" y="158" font-family="Arial" text-anchor="middle" '
-    'font-size="22" fill="white">{base_4_summary}'
+    'font-size="{base_4_size}" fill="white">{base_4_summary}'
     '<title id="title">{base_4_title}</title>'
     '</text>'
 )
@@ -639,19 +649,19 @@ SVG_BASE_4_OUT_TEMPLATE = (
     '<text x="199" y="93" font-family="Arial" text-anchor="start" '
     'font-size="22">{base_2_number}</text>'
     '<text x="199" y="114" font-family="Arial" text-anchor="start" '
-    'font-size="22">{base_2_summary}'
+    'font-size="{base_2_size}">{base_2_summary}'
     '<title id="title">{base_2_title}</title>'
     '</text>'
     '<text x="132" y="93" font-family="Arial" text-anchor="end" '
     'font-size="22">{base_3_number}</text>'
     '<text x="132" y="114" font-family="Arial" text-anchor="end" '
-    'font-size="22">{base_3_summary}'
+    'font-size="{base_3_size}">{base_3_summary}'
     '<title id="title">{base_3_title}</title>'
     '</text>'
     '<text x="164" y="133" font-family="Arial" text-anchor="middle" '
     'font-size="22">{base_4_number}</text>'
     '<text x="164" y="158" font-family="Arial" text-anchor="middle" '
-    'font-size="22">{base_4_summary}'
+    'font-size="{base_4_size}">{base_4_summary}'
     '<title id="title">{base_4_title}</title>'
     '</text>'
 )
@@ -664,7 +674,7 @@ SVG_OUT_TEMPLATE = (
 )
 
 SVG_FIELDING_TEMPLATE = (
-    '<text x="165" y="68" font-family="Arial" font-size="43" '
+    '<text x="165" y="68" font-family="Arial" font-size="{size}" '
     'text-anchor="middle">{summary}'
     '<title id="title">{title}</title>'
     '</text>'
@@ -690,7 +700,7 @@ SVG_COUNT_TEMPLATE = (
 )
 
 SVG_RUNNER_TEMPLATE = ('<text x="70" y="{y_val}" font-family="Arial" '
-                       'stroke="{color}" font-size="16" '
+                       'stroke="{color}" fill="{color}" font-size="16" '
                        'text-anchor="start">{summary}'
                        '<title id="title">{title}</title></text>')
 
@@ -772,15 +782,27 @@ def get_summary_svg(plate_appearance):
                 title=plate_appearance.plate_appearance_description
             )
         else:
+            if len(plate_appearance.scorecard_summary) < 9:
+                size = SUMMARY_SIZE_LARGE
+            else:
+                size = SUMMARY_SIZE_SMALL
+
             return_str = SVG_FIELDING_TEMPLATE.format(
                 summary=plate_appearance.scorecard_summary.replace('ꓘ', 'K'),
-                title=plate_appearance.plate_appearance_description
+                title=plate_appearance.plate_appearance_description,
+                size=size
             )
 
     if plate_appearance.got_on_base and plate_appearance.error_str:
+        if len(plate_appearance.scorecard_summary) < 9:
+            size = SUMMARY_SIZE_LARGE
+        else:
+            size = SUMMARY_SIZE_SMALL
+
         return_str += SVG_FIELDING_TEMPLATE.format(
             summary=plate_appearance.error_str,
-            title=plate_appearance.plate_appearance_description
+            title=plate_appearance.plate_appearance_description,
+            size=size
         )
 
     return return_str
@@ -806,10 +828,7 @@ def process_pitch_position(event):
         )
 
         y_scale_factor = event.pitch_position[1] / PITCH_MAX_COORD
-        y_coord = int(
-            PITCH_Y_MIN + (PITCH_BOX_HEIGHT *
-                                     y_scale_factor)
-        )
+        y_coord = int(PITCH_Y_MIN + (PITCH_BOX_HEIGHT * y_scale_factor))
 
     return x_coord, y_coord
 
@@ -922,7 +941,7 @@ def get_runner_end_base_str(plate_appearance, event):
         for out_runner, out_base in plate_appearance.out_runners_list:
             if out_runner == event.runner:
                 this_end_base_str = out_base[0]
-                if this_end_base_str == 'h' or this_end_base_str == 's':
+                if this_end_base_str in ['h', 's']:
                     this_end_base_str = 'H'
 
     return this_end_base_str
@@ -968,22 +987,21 @@ def get_runners_svg(plate_appearance):
 
         if color:
             summary = '{}-{}'.format(start_base_num, this_end_base)
-            is_forceout_desc = ('Forceout' in runner_event.run_description or
-                                ('Double Play' in runner_event.run_description and
-                                 'F' not in plate_appearance.scorecard_summary and
-                                 'L' not in plate_appearance.scorecard_summary) or
-                                ('Triple Play' in runner_event.run_description and
-                                 'F' not in plate_appearance.scorecard_summary and
-                                 'L' not in plate_appearance.scorecard_summary) or
-                                ('DP' in runner_event.run_description and
-                                 'F' not in plate_appearance.scorecard_summary and
-                                 'L' not in plate_appearance.scorecard_summary) or
-                                ('TP' in runner_event.run_description and
-                                 'F' not in plate_appearance.scorecard_summary and
-                                 'L' not in plate_appearance.scorecard_summary))
+            is_forceout_desc = (
+                'Forceout' in runner_event.run_description or
+                (
+                    ('Double Play' in runner_event.run_description or
+                     'Triple Play' in runner_event.run_description or
+                     'DP' in runner_event.run_description or
+                     'TP' in runner_event.run_description)
+                    and
+                    ('F' not in plate_appearance.scorecard_summary and
+                     'L' not in plate_appearance.scorecard_summary)
+                )
+            )
 
-            if (is_forceout_desc and runner_event.end_base == '' and this_end_base and
-                    not runner_event.runner_scored):
+            if (is_forceout_desc and runner_event.end_base == ''
+                    and this_end_base and not runner_event.runner_scored):
                 summary += 'f'
 
             title_flag_str = get_runner_title_str(runner_event)
@@ -1076,6 +1094,24 @@ def get_all_base_components(base_2_pa, base_3_pa, home_pa):
             base_4_summary,
             base_4_title)
 
+def get_base_font_size(base_2_summary, base_3_summary, base_4_summary):
+    if base_2_summary and len(base_2_summary) > 6:
+        base_2_size = BASE_SVG_FONT_SMALL
+    else:
+        base_2_size = BASE_SVG_FONT_BIG
+
+    if base_3_summary and len(base_3_summary) > 6:
+        base_3_size = BASE_SVG_FONT_SMALL
+    else:
+        base_3_size = BASE_SVG_FONT_BIG
+
+    if base_4_summary and len(base_4_summary) > 6:
+        base_4_size = BASE_SVG_FONT_SMALL
+    else:
+        base_4_size = BASE_SVG_FONT_BIG
+
+    return base_2_size, base_3_size, base_4_size
+
 def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                              batter_out_base):
     (base_2_number,
@@ -1088,14 +1124,20 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
      base_4_summary,
      base_4_title) = get_all_base_components(base_2_pa, base_3_pa, home_pa)
 
+    base_2_size, base_3_size, base_4_size = get_base_font_size(base_2_summary,
+                                                               base_3_summary,
+                                                               base_4_summary)
+
     if batter_out_base:
         if batter_out_base == '1B':
             base_svg = ''
         elif batter_out_base == '2B':
+
             base_svg = SVG_BASE_2_OUT_TEMPLATE.format(
                 base_2_number=base_2_number,
                 base_2_summary=base_2_summary,
-                base_2_title=base_2_title
+                base_2_title=base_2_title,
+                base_2_size=base_2_size
             )
         elif batter_out_base == '3B':
             base_svg = SVG_BASE_3_OUT_TEMPLATE.format(
@@ -1104,7 +1146,9 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_2_title=base_2_title,
                 base_3_number=base_3_number,
                 base_3_summary=base_3_summary,
-                base_3_title=base_3_title
+                base_3_title=base_3_title,
+                base_2_size=base_2_size,
+                base_3_size=base_3_size
             )
         elif batter_out_base == 'H':
             base_svg = SVG_BASE_4_OUT_TEMPLATE.format(
@@ -1116,7 +1160,10 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_3_title=base_3_title,
                 base_4_number=base_4_number,
                 base_4_summary=base_4_summary,
-                base_4_title=base_4_title
+                base_4_title=base_4_title,
+                base_2_size=base_2_size,
+                base_3_size=base_3_size,
+                base_4_size=base_4_size
             )
         else:
             raise ValueError('Invalid Base')
@@ -1127,7 +1174,8 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
             base_svg = SVG_BASE_2_TEMPLATE.format(
                 base_2_number=base_2_number,
                 base_2_summary=base_2_summary,
-                base_2_title=base_2_title
+                base_2_title=base_2_title,
+                base_2_size=base_2_size
             )
         elif batter_final_base == '3B':
             base_svg = SVG_BASE_3_TEMPLATE.format(
@@ -1136,7 +1184,9 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_2_title=base_2_title,
                 base_3_number=base_3_number,
                 base_3_summary=base_3_summary,
-                base_3_title=base_3_title
+                base_3_title=base_3_title,
+                base_2_size=base_2_size,
+                base_3_size=base_3_size
             )
         elif batter_final_base == 'H':
             base_svg = SVG_BASE_4_TEMPLATE.format(
@@ -1148,7 +1198,10 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_3_title=base_3_title,
                 base_4_number=base_4_number,
                 base_4_summary=base_4_summary,
-                base_4_title=base_4_title
+                base_4_title=base_4_title,
+                base_2_size=base_2_size,
+                base_3_size=base_3_size,
+                base_4_size=base_4_size
             )
         else:
             raise ValueError('Invalid Base')
@@ -1193,7 +1246,7 @@ def fix_pa(plate_appearance, event):
         description = '{} batting: Defensive Indifference'.format(
             plate_appearance.batter
         )
-    elif 'Pickoff Error' in event.run_description:
+    elif 'Error' in event.run_description:
         summary = 'E'
         description = '{} batting: {}'.format(
             plate_appearance.batter,
@@ -1211,10 +1264,12 @@ def fix_pa(plate_appearance, event):
 
 def get_base_svg(plate_appearance, plate_appearance_list):
     plate_appearance_index = plate_appearance_list.index(plate_appearance)
-    plate_appearance_list = plate_appearance_list[plate_appearance_index:plate_appearance_index+8]
+    plate_appearance_list = (
+        plate_appearance_list[plate_appearance_index:plate_appearance_index+8]
+    )
 
-    first_base_pa, second_base_pa, third_base_pa, home_plate_pa = None, None, None, None
-    batter_final_base, batter_out_base, batter_is_done = None, None, None
+    second_base_pa = third_base_pa = home_plate_pa = None
+    batter_final_base = batter_out_base = batter_is_done = None
 
     batter = plate_appearance.batter
     for this_pa in plate_appearance_list:
@@ -1235,8 +1290,6 @@ def get_base_svg(plate_appearance, plate_appearance_list):
                     if out_runner == batter:
                         if out_base == '1st':
                             batter_out_base = '1B'
-                            if plate_appearance != this_pa:
-                                first_base_pa = fix_pa(this_pa, event)
                         elif out_base == '2nd':
                             batter_out_base = '2B'
                             if plate_appearance != this_pa:
@@ -1250,9 +1303,11 @@ def get_base_svg(plate_appearance, plate_appearance_list):
                             if plate_appearance != this_pa:
                                 home_plate_pa = fix_pa(this_pa, event)
 
-                if event.end_base == '1B' and batter_final_base not in ['2B', '3B', 'H']:
+                if (event.end_base == '1B' and
+                        batter_final_base not in ['2B', '3B', 'H']):
                     batter_final_base = '1B'
-                elif event.end_base == '2B' and batter_final_base not in ['3B', 'H']:
+                elif (event.end_base == '2B' and
+                      batter_final_base not in ['3B', 'H']):
                     batter_final_base = '2B'
                     if plate_appearance != this_pa:
                         second_base_pa = fix_pa(this_pa, event)
@@ -1433,7 +1488,8 @@ def get_batter_spacing_values(batter_list):
         )
 
     for batter in batter_list:
-        if len(str(batter.player_obj)) > 18 and batter_font_size == BATTER_FONT_SIZE_BIG:
+        if (len(str(batter.player_obj)) > 18 and
+                batter_font_size == BATTER_FONT_SIZE_BIG):
             batter_font_size = BATTER_FONT_SIZE_MED_PLUS
             batter_space_increment = BATTER_SPACE_MED_PLUS
             stats_y_offset = BATTER_STATS_OFFSET_MED_PLUS
@@ -1729,26 +1785,43 @@ def add_away_pitcher_sub_division_lines(game):
                 if not inning.bottom_half_appearance_list:
                     continue
 
+                num_appearances = len(inning.bottom_half_appearance_list)
+                mod_num = num_appearances % LEN_BATTING_LIST
                 for appearance in inning.bottom_half_appearance_list:
                     if (inning_num == pitcher_app.end_inning_num and
                             (inning_pa_num == pitcher_app.end_inning_batter_num
                              or pitcher_app.end_inning_half == 'top')):
 
-                        x_pos = (BOX_WIDTH *
-                                 pitcher_app.end_inning_num)
-
+                        x_pos = BOX_WIDTH * pitcher_app.end_inning_num
+                        x_pos_2 = x_pos + BOX_WIDTH
                         y_pos = (
-                            (BOX_HEIGHT *
-                             (total_pa_num % LEN_BATTING_LIST)) +
+                            (BOX_HEIGHT * (total_pa_num % LEN_BATTING_LIST)) +
                             (HEIGHT // 2 + BOX_HEIGHT // 2)
                         )
 
+                        if ((LEN_BATTING_LIST * 2) >= num_appearances >
+                                LEN_BATTING_LIST):
+                            if inning_pa_num <= mod_num:
+                                x_pos_2 -= (BOX_WIDTH // 2)
+                            elif inning_pa_num > LEN_BATTING_LIST:
+                                x_pos += (BOX_WIDTH // 2)
+                                y_pos += (BOX_HEIGHT // 2)
+                        elif num_appearances > (LEN_BATTING_LIST * 2):
+                            if inning_pa_num <= mod_num:
+                                x_pos_2 -= (BOX_WIDTH // 2)
+                            elif inning_pa_num > LEN_BATTING_LIST:
+                                x_pos += (BOX_WIDTH // 2)
+                            elif inning_pa_num > (LEN_BATTING_LIST * 2):
+                                x_pos_2 -= (BOX_WIDTH // 2)
+                                y_pos += (BOX_HEIGHT // 2)
+                            elif inning_pa_num > (LEN_BATTING_LIST * 3):
+                                x_pos += (BOX_WIDTH // 2)
+                                y_pos += (BOX_HEIGHT // 2)
+
                         sub_divisions_svg += (
-                            PITCHER_SUB_DIVISION_LINE.format(
-                                x_pos_1=x_pos,
-                                x_pos_2=x_pos + BOX_WIDTH,
-                                y_pos=y_pos
-                            )
+                            PITCHER_SUB_DIVISION_LINE.format(x_pos_1=x_pos,
+                                                             x_pos_2=x_pos_2,
+                                                             y_pos=y_pos)
                         )
 
                     if appearance.plate_appearance_summary != 'Runner Out':
@@ -1860,7 +1933,8 @@ def get_pitcher_box_score_lines(pitcher_app_list, chunk_size, box_score_dict):
         defined_text_increment = PITCHER_BOX_SCORE_SMALL_Y_INCREMENT
 
     for pitcher_app in pitcher_app_list:
-        if len(str(pitcher_app.player_obj)) > 18 and chunk_size == SMALL_CHUNK_SIZE:
+        if (len(str(pitcher_app.player_obj)) > 18 and
+                chunk_size == SMALL_CHUNK_SIZE):
             initial_y = PITCHER_BOX_SCORE_MED_Y
             text_size_1 = PITCHER_MED_FONT_SIZE
             text_size_2 = PITCHER_STATS_MED_FONT_SIZE
@@ -2070,7 +2144,7 @@ def get_logo(game):
 
     x_pos = game_width - BOX_WIDTH
     y_pos = 8 * BOX_HEIGHT + BOX_HEIGHT // 2 + HEIGHT // 2
-    home_logo_str = LOGO_DICT[game.home_team.abbreviation]
+    home_logo_str = LOGO_DICT.get(game.home_team.abbreviation, DEFAULT_LOGO)
     signature_svg += HOME_LOGO.format(x_pos=x_pos,
                                       y_pos=y_pos,
                                       logo=home_logo_str)
@@ -2080,12 +2154,26 @@ def get_logo(game):
 def write_individual_pa_svg(svg_content, inning_pa_num, this_inning_tuple_list,
                             this_x_pos, this_y_pos):
     this_svg = ''
-    bat_around_flag = is_bat_around(this_inning_tuple_list, inning_pa_num)
-    if bat_around_flag:
+    bat_around_flag = False
+    if len(this_inning_tuple_list) <= (LEN_BATTING_LIST * 2):
+        if is_bat_around(this_inning_tuple_list, inning_pa_num):
+            bat_around_flag = True
+            this_svg += HALF_SCALE_HEADER
+            this_x_pos *= 2
+            this_y_pos *= 2
+            if inning_pa_num > LEN_BATTING_LIST:
+                this_y_pos += BOX_HEIGHT
+                this_x_pos += BOX_WIDTH
+    else:
+        bat_around_flag = True
         this_svg += HALF_SCALE_HEADER
         this_x_pos *= 2
         this_y_pos *= 2
-        if inning_pa_num > 9:
+        if LEN_BATTING_LIST < inning_pa_num <= (LEN_BATTING_LIST * 2):
+            this_x_pos += BOX_WIDTH
+        elif (LEN_BATTING_LIST * 2) < inning_pa_num <= (LEN_BATTING_LIST * 3):
+            this_y_pos += BOX_HEIGHT
+        elif (LEN_BATTING_LIST * 3) < inning_pa_num:
             this_x_pos += BOX_WIDTH
             this_y_pos += BOX_HEIGHT
 
@@ -2151,10 +2239,44 @@ def get_game_title_str(game):
 def assemble_game_title_svg(game):
     game_title_svg = ''
     game_str = '{} @ {}'.format(game.away_team.name, game.home_team.name)
-    if game.start_str and game.end_str:
-        game_datetime = '{}{}'.format(game.start_str, game.end_str)
+    this_start_datetime = (game.start_datetime if game.start_datetime
+                           else game.expected_start_datetime)
+
+    if this_start_datetime:
+        this_start_datetime = this_start_datetime.astimezone(
+            timezone(game.timezone_str)
+        )
+
+        est_time = this_start_datetime.astimezone(
+            timezone(EASTERN_TIMEZONE_STR)
+        )
+
+        if ((est_time.hour == 23 and est_time.minute == 33) or
+                (est_time.hour == 0 and est_time.minute == 0)):
+            game_datetime = '{}'.format(
+                this_start_datetime.strftime('%a %b %d %Y')
+            )
+        elif game.start_datetime and game.end_datetime:
+            start_str = game.start_datetime.astimezone(
+                timezone(game.timezone_str)
+            ).strftime('%a %b %d %Y, %-I:%M %p')
+
+            end_str = game.end_datetime.astimezone(
+                timezone(game.timezone_str)
+            ).strftime(' - %-I:%M %p %Z')
+
+            game_datetime = '{}{}'.format(start_str, end_str)
+        else:
+            game_datetime = game.expected_start_datetime.astimezone(
+                timezone(game.timezone_str)
+            ).strftime('%a %b %d %Y, %-I:%M %p %Z')
+
+        if game.is_doubleheader:
+            game_datetime += ', Game {}'.format(game.game_date_str[-1])
+        elif game.is_postponed:
+            game_datetime += ', Postponed'
     else:
-        game_datetime = game.game_date_str
+        game_datetime = ''
 
     game_width = get_game_width(game)
     location_str = game.location.replace('&', '&amp;')
@@ -2176,6 +2298,7 @@ def assemble_game_title_svg(game):
 
     tuple_list = [('TOP', 0), ('BOTTOM', HEIGHT // 2)]
     for inning_half_str, y_pos in tuple_list:
+        title_size = BIG_TITLE_SIZE if len(game_str) < 42 else SMALL_TITLE_SIZE
         game_title_svg += BIG_SVG_TITLE.format(
             x_pos=game_width - BOX_WIDTH,
             y_pos=y_pos,
@@ -2183,7 +2306,8 @@ def assemble_game_title_svg(game):
             game_str=game_str,
             location=location_str,
             datetime=game_datetime,
-            detail_str=detail_str
+            detail_str=detail_str,
+            title_size=title_size
         )
 
     return game_title_svg
