@@ -1,6 +1,7 @@
 from datetime import datetime
 from re import search, sub
 
+from dateutil.parser import parse
 from pytz import UTC
 
 from baseball.baseball import (POSITION_CODE_DICT,
@@ -18,7 +19,6 @@ from baseball.baseball_events import (AUTOMATIC_BALL_POSITION,
                                       Substitution,
                                       Switch)
 
-
 MLB_TEAM_CODE_DICT = {'LAA': 'ana',
                       'SEA': 'sea',
                       'BAL': 'bal',
@@ -32,6 +32,7 @@ MLB_TEAM_CODE_DICT = {'LAA': 'ana',
                       'HOU': 'hou',
                       'OAK': 'oak',
                       'MIA': 'mia',
+                      'FLO': 'flo',
                       'ATL': 'atl',
                       'MIL': 'mil',
                       'CHC': 'chn',
@@ -59,8 +60,10 @@ POSITION_ABBREV_DICT = {'P': 1,
                         'LF': 7,
                         'CF': 8,
                         'RF': 9,
-                        'DH': 10}
-
+                        'DH': 10,
+                        'PH': 'PH',
+                        'PR': 'PR',
+                        'EH': 'EH'}
 
 def get_team_abbreviation(mlb_code):
     for abbreviation, this_mlb_code in MLB_TEAM_CODE_DICT.items():
@@ -258,16 +261,14 @@ def parse_substitution(substitution_datetime, description, event_summary,
 
     position_num = get_position_number(position_str)
 
-    if (event_summary == 'Pitching Substitution' or
-            event_summary == 'Defensive Sub' or
-            event_summary == 'Defensive sub'):
+    if (event_summary  in ['Pitching Substitution', 'Defensive Sub',
+                           'Defensive sub']):
         if inning_half_str == 'top':
             this_team = game_obj.home_team
         else:
             this_team = game_obj.away_team
-    elif (event_summary == 'Offensive Sub' or
-          event_summary == 'Offensive sub' or
-          event_summary == 'Offensive Substitution'):
+    elif (event_summary in ['Offensive Sub', 'Offensive sub',
+                            'Offensive Substitution']):
         if inning_half_str == 'top':
             this_team = game_obj.away_team
         else:
@@ -300,12 +301,6 @@ def get_position_number(position_str):
         position = POSITION_CODE_DICT[position_str]
     elif position_str in POSITION_ABBREV_DICT:
         position = POSITION_ABBREV_DICT[position_str]
-    elif position_str == 'PH':
-        position = 'PH'
-    elif position_str == 'PR':
-        position = 'PR'
-    elif position_str == 'EH':
-        position = 'EH'
     elif not position_str:
         position = None
     else:
@@ -427,7 +422,8 @@ def process_substitution(substitution_obj, inning_num, inning_half_str,
                          for batting_list in batting_list_list]
 
         duplicate_position_set = set(
-            [x for x in position_list if ((position_list.count(x) > 1) and (x not in ['PH', 'PR']))]
+            [x for x in position_list
+             if ((position_list.count(x) > 1) and (x not in ['PH', 'PR']))]
         )
 
         if duplicate_position_set:
@@ -460,8 +456,9 @@ def process_substitution(substitution_obj, inning_num, inning_half_str,
 
     if not player_appearance_list:
         for this_appearance_list in batting_list_list:
+            outgoing_id = substitution_obj.outgoing_player.mlb_id
             if (len(this_appearance_list) > 1 and
-                    this_appearance_list[-2].player_obj.mlb_id == substitution_obj.outgoing_player.mlb_id):
+                    this_appearance_list[-2].player_obj.mlb_id == outgoing_id):
                 player_appearance_list = this_appearance_list
 
     if player_appearance_list:
@@ -606,7 +603,7 @@ def get_sub_switch_steal_flags(event_summary, event_description):
     return substitution_flag, switch_flag, steal_flag
 
 def process_half_inning(baseball_half_inning, inning_half_str, game_obj):
-    if inning_half_str != 'top' and inning_half_str != 'bottom':
+    if inning_half_str not in ['top', 'bottom']:
         raise ValueError('Invalid inning half str.')
 
     plate_appearance_list = []
@@ -815,7 +812,9 @@ def initialize_game_object(boxscore_xml):
     home_name = boxscore_xml.get('home_fname')
     away_code = get_team_abbreviation(boxscore_xml.get('away_team_code'))
     away_name = boxscore_xml.get('away_fname')
-    boxscore_date = boxscore_xml.get('date')
+    game_id = boxscore_xml.get('game_id')
+    game_number = int(game_id[-1])
+    date_str = game_id.rsplit('/', 1)[0].replace('/', '-')
 
     home_pitcher_status_dict = {}
     away_pitcher_status_dict = {}
@@ -872,13 +871,20 @@ def initialize_game_object(boxscore_xml):
                 weather = match.group(2)
                 attendance = int(match.group(3).replace(',', ''))
 
-    game_obj = Game(home_team, away_team, game_venue, boxscore_date)
+
+    game_date_str = '{}-{}-{}-{}'.format(date_str, away_team.abbreviation,
+                                         home_team.abbreviation, game_number)
+
+    game_obj = Game(home_team, away_team, game_venue, game_date_str)
+
     if temp:
         game_obj.temp = temp
     if weather:
         game_obj.weather = weather
     if attendance:
         game_obj.attendance = attendance
+    if boxscore_xml.get('date'):
+        game_obj.expected_start_datetime = parse(boxscore_xml.get('date'))
 
     return (game_obj,
             away_pitcher_status_dict,
